#include "ocf4mfc.h"

DIAG_DEFINE_GROUP(OCF4MFC, true, 1);


////////////////////////////////////////////////////////////////////////////
//
//
IMPLEMENT_DYNAMIC(CMDIFrameOCF, CMDIFrameWnd)
BEGIN_MESSAGE_MAP(CMDIFrameOCF, CMDIFrameWnd)
  //{{AFX_MSG_MAP(CMDIFrameOCF)
  ON_WM_CREATE()
  ON_WM_DESTROY()

  ON_MESSAGE(WM_OCEVENT, OnOcEvent)
  //}}AFX_MSG_MAP
END_MESSAGE_MAP()



int  
CMDIFrameOCF::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
  int val = CMDIFrameWnd::OnCreate(lpCreateStruct);
  OCFHlpr = new TOleFrameWin(m_hWnd);
  OCFHlpr->OnCreate();

  TRACEX(OCF4MFC, 1, "OnCreate: (" << hex << uint(m_hWnd) << ')' );

  return val;
}


void 
CMDIFrameOCF::OnDestroy()
{
  CMDIFrameWnd::OnDestroy();    

  OCFHlpr->OnDestroy();
  delete OCFHlpr;
  OCFHlpr = 0;
}


//
// Handles OCAPPFRAMERECT
//
bool
CMDIFrameOCF::OnOcAppFrameRect(HWND hwnd, TRect far* rect)
{
  GetClientRect(*((CRect*)rect));
  return true;
}


//
// Pass on OCAPPINSMENU to active child so it may merge in its menu
//
bool
CMDIFrameOCF::OnOcAppInsMenus(HWND hwnd, TOcMenuDescr far* sharedMenu)
{
  return false;
}


//
// Set menu handle specified by active child
//
bool
CMDIFrameOCF::OnOcAppMenus(HWND hwnd, TOcMenuDescr far* menuDescr)
{
  return false;
}


bool
CMDIFrameOCF::OnOcAppProcessMsg(HWND, MSG far*)
{
  return false;
}


bool
CMDIFrameOCF::OnOcAppBorderSpaceReq(HWND, TRect far*)
{
  return true;  // We'll negotiate anything!
}


bool
CMDIFrameOCF::OnOcAppBorderSpaceSet(HWND hwnd, TRect far* rect)
{
  return false;
}


//
//
//
void
CMDIFrameOCF::OnOcAppStatusText(HWND, const char far* /*text*/)
{
}


//
//
//
void
CMDIFrameOCF::OnOcAppRestoreUI(HWND hwnd)
{
}


LRESULT
CMDIFrameOCF::OnOcEvent(WPARAM wParam, LPARAM lParam)
{
  TRACEX(OCF4MFC, 1, "WM_OCEVENT: (" << hex << uint(m_hWnd) <<
         ") " << GetOcString(wParam));

  switch (wParam) {
    HANDLE_OCF(m_hWnd, OC_APPFRAMERECT,       OnOcAppFrameRect);
    HANDLE_OCF(m_hWnd, OC_APPBORDERSPACESET,  OnOcAppBorderSpaceSet);
    HANDLE_OCF(m_hWnd, OC_APPBORDERSPACEREQ,  OnOcAppBorderSpaceReq);
    HANDLE_OCF(m_hWnd, OC_APPINSMENUS,        OnOcAppInsMenus);
    HANDLE_OCF(m_hWnd, OC_APPMENUS,           OnOcAppMenus);
    HANDLE_OCF(m_hWnd, OC_APPRESTOREUI,       OnOcAppRestoreUI);

    default:
      return 0;
  }
}



////////////////////////////////////////////////////////////////////////////
//
//
BEGIN_MESSAGE_MAP(CMDIChildOCF, CMDIChildWnd)
  //{{AFX_MSG_MAP(CMDIChildOCF)
  ON_WM_CREATE()
  ON_WM_DESTROY()  
                      
  ON_WM_LBUTTONDOWN()
  ON_WM_LBUTTONDBLCLK()

  ON_WM_SIZE()

  ON_UPDATE_COMMAND_UI(CM_EDITINSERTOBJECT, OnUpdateInsertObject)
  ON_COMMAND(CM_EDITINSERTOBJECT, OnInsertObject)

  ON_MESSAGE(WM_OCEVENT, OnOcEvent)

  //}}AFX_MSG_MAP
END_MESSAGE_MAP()


int  
CMDIChildOCF::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
  OCFHlpr = new TOleWin(m_hWnd);
  OCFHlpr->OnCreate();

  return CMDIChildWnd::OnCreate(lpCreateStruct);
}


void 
CMDIChildOCF::OnDestroy()
{
  CMDIChildWnd::OnDestroy();    

  OCFHlpr->OnDestroy();
  delete OCFHlpr;
  OCFHlpr = 0;
}


void 
CMDIChildOCF::OnLButtonDown(UINT nFlags, CPoint pt)
{
  if (!OCFHlpr->OnLButtonDown(pt.x, pt.y, nFlags))
    CMDIChildWnd::OnLButtonDown(nFlags, pt);
}


void 
CMDIChildOCF::OnLButtonDblClk(UINT nFlags, CPoint pt)
{
  if (!OCFHlpr->OnLButtonDblClk(pt.x, pt.y, nFlags))
    CMDIChildWnd::OnLButtonDblClk(nFlags, pt);
}


void
CMDIChildOCF::OnSize(UINT type, int cx, int cy)
{
  OCFHlpr->OnSize();
  CMDIChildWnd::OnSize(type, cx, cy);
}


void 
CMDIChildOCF::OnUpdateInsertObject(CCmdUI* pCmdUI)
{
  pCmdUI->Enable(GetOcApp() && OCFHlpr->GetOcView());
}


void 
CMDIChildOCF::OnInsertObject()
{
  OCFHlpr->EditInsertObject();
}


LRESULT
CMDIChildOCF::OnOcEvent(WPARAM wParam, LPARAM lParam)
{
  TRACEX(OCF4MFC, 1, "WM_OCEVENT: (" << hex << uint(m_hWnd) <<
         ") " << GetOcString(wParam));

  return OCFHlpr->OnOcEvent(wParam, lParam);
}
